==> hinemos_client-2.1.1_rhel4.tar.gz: Hinemos_Client-2.1.1_rhel4/client_installer_EN.sh <==
#!/bin/sh

#Copyright (C) 2006 NTT DATA Corporation
#
#This program is free software; you can redistribute it and/or
#Modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation, version 2.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details

EXEC_PATH=${0%/*}

echo "###################################################################"
echo "###                                                             ###"
echo "### Operation Management Software Hinemos Client                ###"
echo "###                                      Installer   Ver 2.1    ###"
echo "###                                                             ###"
echo "###  2006/9/29                                                  ###"
echo "###  Copyright (C) 2006 NTT DATA Corporation.                   ###"
echo "###################################################################"


#設定情報読み込み
. ${0%/*}/install.cfg

while [ 1 ];
do
	echo "Hinemos Client's"
	echo "     1) Install"
	echo "     9) Quit this installer"
	echo ""
	echo -n "===> "
	
	read CHOSEN_NUMBER

	case ${CHOSEN_NUMBER} in
	1)
		echo ""
	
		while [ 1 ];
		do
			echo ""
			echo "An installation will be started. Is it all right (Y/N)?"
			read ANS
			case ${ANS} in
				y|Y)
					# インストール準備部分
					echo "Input directory for install Hinemos client (dafault: ~/hinemos_client)."
					echo "When you have installed except a root user, please give writable authority to the Hinemos client user."
				
					read HINEMOS_CLIENT_HOME
<                                       HINEMOS_CLIENT_HOME=${HINEMOS_CLIENT_HOME:-$HOME/hinemos_client}
	
					if [ ! -d ${HINEMOS_CLIENT_HOME} ]; then
					    echo "${HINEMOS_CLIENT_HOME}は存在しません。作成します。"
					    mkdir -p ${HINEMOS_CLIENT_HOME}
					   if [ $? -ne 0 ] ; then
    					       exit 2
 					   fi
					   echo ""
					fi
	
					# クライアント該当部分をコピーする。
					echo "Copying the required files."
					cp -pr ${EXEC_PATH}/hinemos_client/* ${HINEMOS_CLIENT_HOME}
					echo "The Copying the required files was finished."

                                        echo "Installing JRE"
                                        sleep 2
                                        echo ""
                                        cp ${EXEC_PATH}/jre-1_5_0_09-linux-i586.bin ${HINEMOS_CLIENT_HOME}
                                        CURRENT_DIR=`pwd`
                                        cd ${HINEMOS_CLIENT_HOME}
                                        ${HINEMOS_CLIENT_HOME}/jre-1_5_0_09-linux-i586.bin
                                        rm ${HINEMOS_CLIENT_HOME}/jre-1_5_0_09-linux-i586.bin
                                        cd $CURRENT_DIR

					
				       REPLACE_PATH=`echo $HINEMOS_CLIENT_HOME | sed 's/\//\\\\\//g'`
                                       sed "s/%%hinemos_client_install_dir%%/$REPLACE_PATH/" $EXEC_PATH/hinemos_client.cfg > $HINEMOS_CLIENT_HOME/hinemos_client.cfg
                                       sed "s/%%hinemos_client_install_dir%%/$REPLACE_PATH/" $EXEC_PATH/hinemos_client.sh > $HINEMOS_CLIENT_HOME/hinemos_client.sh
                                       chmod 700 $HINEMOS_CLIENT_HOME/hinemos_client.sh

					#起動スクリプト設定
#					sed -e "s%\%\%HinemosHome\%\%%${HINEMOS_CLIENT_HOME}%" -e "s/%%ClientJRE%%/${JRE_NAME}/" $EXEC_PATH/scripts/hinemos_client.sh > ${HINEMOS_CLIENT_HOME}/hinemos_client.sh
#					chmod +x ${HINEMOS_CLIENT_HOME}/hinemos_client.sh
					echo ""	
					echo ""	
					echo "The installation of Hinemos client was completed."
					echo "${HINEMOS_CLIENT_HOME}/hinemos_client.sh can start up Hinemos client."	
					echo ""	
					echo ""	
					break
					;;

				n|N)
					echo "Installation is stopped and return to the menu."
					echo ""
					sleep 1
					break
					;;

			    *)
				;;
			esac

		done
		;;
	9)
		echo "Hinemos installer is finished."
		exit
		;;
	*)
		echo ""
		sleep 1
		;;
  esac
done

==> hinemos_client-2.2.0_rhel4.tar.gz: Hinemos_Client-2.2.0_rhel4/client_installer_EN.sh <==
#!/bin/sh

#Copyright (C) 2006, 2007 NTT DATA Corporation
#
#This program is free software; you can redistribute it and/or
#Modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation, version 2.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details

EXEC_PATH=${0%/*}

echo "###################################################################"
echo "###                                                             ###"
echo "### Operation Management Software Hinemos Client                ###"
echo "###                                      Installer   Ver 2.2.0  ###"
echo "###                                                             ###"
echo "###  2006/03/28                                                 ###"
echo "###  Copyright (C) 2006, 2007 NTT DATA Corporation.             ###"
echo "###################################################################"


#設定情報読み込み
. ${0%/*}/install.cfg

while [ 1 ];
do
	echo "Hinemos Client's"
	echo "     1) Install"
	echo "     9) Quit this installer"
	echo ""
	echo -n "===> "
	
	read CHOSEN_NUMBER

	case ${CHOSEN_NUMBER} in
	1)
		echo ""
	
		while [ 1 ];
		do
			echo ""
			echo "An installation will be started. Is it all right (Y/N)?"
			read ANS
			case ${ANS} in
				y|Y)
					# インストール準備部分
					echo "Input directory for install Hinemos client (dafault: ~/hinemos_client)."
					echo "When you have installed except a root user, please give writable authority to the Hinemos client user."
				
					read HINEMOS_CLIENT_HOME
<                                       HINEMOS_CLIENT_HOME=${HINEMOS_CLIENT_HOME:-$HOME/hinemos_client}
	
					if [ ! -d ${HINEMOS_CLIENT_HOME} ]; then
					    echo "${HINEMOS_CLIENT_HOME}は存在しません。作成します。"
					    mkdir -p ${HINEMOS_CLIENT_HOME}
					   if [ $? -ne 0 ] ; then
    					       exit 2
 					   fi
					   echo ""
					fi
	
					# クライアント該当部分をコピーする。
					echo "Copying the required files."
					cp -pr ${EXEC_PATH}/hinemos_client/* ${HINEMOS_CLIENT_HOME}
					echo "The Copying the required files was finished."

                                        echo "Installing JRE"
                                        sleep 2
                                        echo ""
                                        cp ${EXEC_PATH}/jre-1_5_0_09-linux-i586.bin ${HINEMOS_CLIENT_HOME}
                                        CURRENT_DIR=`pwd`
                                        cd ${HINEMOS_CLIENT_HOME}
                                        ${HINEMOS_CLIENT_HOME}/jre-1_5_0_09-linux-i586.bin
                                        rm ${HINEMOS_CLIENT_HOME}/jre-1_5_0_09-linux-i586.bin
                                        cd $CURRENT_DIR

					
				       REPLACE_PATH=`echo $HINEMOS_CLIENT_HOME | sed 's/\//\\\\\//g'`
                                       sed "s/%%hinemos_client_install_dir%%/$REPLACE_PATH/" $EXEC_PATH/hinemos_client.cfg > $HINEMOS_CLIENT_HOME/hinemos_client.cfg
                                       sed "s/%%hinemos_client_install_dir%%/$REPLACE_PATH/" $EXEC_PATH/hinemos_client.sh > $HINEMOS_CLIENT_HOME/hinemos_client.sh
                                       chmod 700 $HINEMOS_CLIENT_HOME/hinemos_client.sh

					#起動スクリプト設定
#					sed -e "s%\%\%HinemosHome\%\%%${HINEMOS_CLIENT_HOME}%" -e "s/%%ClientJRE%%/${JRE_NAME}/" $EXEC_PATH/scripts/hinemos_client.sh > ${HINEMOS_CLIENT_HOME}/hinemos_client.sh
#					chmod +x ${HINEMOS_CLIENT_HOME}/hinemos_client.sh
					echo ""	
					echo ""	
					echo "The installation of Hinemos client was completed."
					echo "${HINEMOS_CLIENT_HOME}/hinemos_client.sh can start up Hinemos client."	
					echo ""	
					echo ""	
					break
					;;

				n|N)
					echo "Installation is stopped and return to the menu."
					echo ""
					sleep 1
					break
					;;

			    *)
				;;
			esac

		done
		;;
	9)
		echo "Hinemos installer is finished."
		exit
		;;
	*)
		echo ""
		sleep 1
		;;
  esac
done
